==> openj9-18_0.33.1.orig.tar.xz: src-openj9-18-0.33.1/omr/compiler/ilgen/OMRJitBuilderRecorderBinaryFile.hpp <==
/*******************************************************************************
 * Copyright (c) 2018, 2018 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at http://eclipse.org/legal/epl-2.0
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License, v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception [1] and GNU General Public
 * License, version 2 with the OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/

#ifndef OMR_JITBUILDERRECORDER_BINARYFILE_INCL
#define OMR_JITBUILDERRECORDER_BINARYFILE_INCL

#include "ilgen/JitBuilderRecorderBinaryBuffer.hpp"

namespace TR { class IlBuilder; }
namespace TR { class MethodBuilder; }
namespace TR { class IlType; }
namespace TR { class IlValue; }

namespace OMR
{

class JitBuilderRecorderBinaryFile : public TR::JitBuilderRecorderBinaryBuffer
   {
   public:
   JitBuilderRecorderBinaryFile(const TR::MethodBuilder *mb, const char *fileName);
   virtual ~JitBuilderRecorderBinaryFile() { }

   virtual void Close();

   };

} // namespace OMR

#endif // !defined(OMR_JITBUILDERRECORDER_BINARYFILE_INCL)

==> openj9-21_0.56.0.orig.tar.xz: src-openj9-21-0.56.0/omr/compiler/ilgen/OMRJitBuilderRecorderBinaryFile.hpp <==
/*******************************************************************************
 * Copyright IBM Corp. and others 2018
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution
 * and is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License, v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception [1] and GNU General Public
 * License, version 2 with the OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 *******************************************************************************/

#ifndef OMR_JITBUILDERRECORDER_BINARYFILE_INCL
#define OMR_JITBUILDERRECORDER_BINARYFILE_INCL

#include "ilgen/JitBuilderRecorderBinaryBuffer.hpp"

namespace TR {
class IlBuilder;
class MethodBuilder;
class IlType;
class IlValue;
} // namespace TR

namespace OMR {

class JitBuilderRecorderBinaryFile : public TR::JitBuilderRecorderBinaryBuffer {
public:
    JitBuilderRecorderBinaryFile(const TR::MethodBuilder *mb, const char *fileName);

    virtual ~JitBuilderRecorderBinaryFile() {}

    virtual void Close();
};

} // namespace OMR

#endif // !defined(OMR_JITBUILDERRECORDER_BINARYFILE_INCL)
